# grohe
A python package to interact with the Grohe API.

## Installation
```python
pip install grohe
```

## Usage
For usage instructions look into the wiki: [Usage](https://github.com/koproductions-code/grohe/wiki/Usage)

## License
This project is licensed under the <MIT> [MIT](https://github.com/koproductions-code/grohe/blob/master/LICENSE) License - see LICENSE file for details.